@@ -78,7 +78,6 @@ class TrainingDatasetApi:
             training_dataset_instance (training_dataset): the metadata instance of the training dataset
             app_options ([type]): the configuration for the training dataset job application
         """
-
         _client = client.get_instance()
         path_params = [
             "project",
@@ -140,9 +139,7 @@ class TrainingDatasetApi:
         )
 
     def get_serving_prepared_statement(self, training_dataset_instance):
-        """
-        ... the training dataset
-
+        """Get serving prepared statement metadata object for a training dataset.
         Args:
             training_dataset_instance (training_dataset): the metadata instance of the training dataset
         """
