@@ -16,7 +16,12 @@
 
 import warnings
 import humps
-from typing import Optional, Union, List, Dict
+import numpy
+import datetime
+from typing import Optional, Union, List, Dict, TypeVar
+
+from hsfs.transformation_function import TransformationFunction
+from hsfs.core import transformation_function_engine
 
 from hsfs import (
     training_dataset,
@@ -87,6 +92,10 @@ class FeatureStore:
 
         self._feature_group_engine = feature_group_engine.FeatureGroupEngine(self._id)
 
+        self._transformation_function_engine = (
+            transformation_function_engine.TransformationFunctionEngine(self._id)
+        )
+
     @classmethod
     def from_response_json(cls, json_dict):
         json_decamelized = humps.decamelize(json_dict)
@@ -378,13 +387,15 @@ class FeatureStore:
         description: Optional[str] = "",
         features: Optional[List[feature.Feature]] = [],
         statistics_config: Optional[Union[StatisticsConfig, bool, dict]] = None,
+        validation_type: Optional[str] = "NONE",
+        expectations: Optional[List[expectation.Expectation]] = [],
     ):
         """Create a on-demand feature group metadata object.
 
         !!! note "Lazy"
-            This method is lazy and does not persist any metadata or feature data in the
-            feature store on its own. To persist the feature group and save feature data
-            along the metadata in the feature store, call the `save()` method.
+            This method is lazy and does not persist any metadata in the
+            feature store on its own. To persist the feature group metadata in the feature store,
+            call the `save()` method.
 
         # Arguments
             name: Name of the on-demand feature group to create.
@@ -414,6 +425,12 @@ class FeatureStore:
                 values should be booleans indicating the setting. To fully turn off
                 statistics computation pass `statistics_config=False`. Defaults to
                 `None` and will compute only descriptive statistics.
+            validation_type: Optionally, set the validation type to one of "NONE", "STRICT",
+                "WARNING", "ALL". Determines the mode in which data validation is applied on
+                 ingested or already existing feature group data.
+            expectations: Optionally, a list of expectations to be attached to the feature group.
+                The expectations list contains Expectation metadata objects which can be retrieved with
+                the `get_expectation()` and `get_expectations()` functions.
 
         # Returns
             `OnDemandFeatureGroup`. The on-demand feature group metadata object.
@@ -431,6 +448,8 @@ class FeatureStore:
             featurestore_name=self._name,
             features=features,
             statistics_config=statistics_config,
+            validation_type=validation_type,
+            expectations=expectations,
         )
 
     def create_training_dataset(
@@ -446,6 +465,7 @@ class FeatureStore:
         seed: Optional[int] = None,
         statistics_config: Optional[Union[StatisticsConfig, bool, dict]] = None,
         label: Optional[List[str]] = [],
+        transformation_functions: Optional[Dict[str, TransformationFunction]] = {},
     ):
         """Create a training dataset metadata object.
 
@@ -525,6 +545,7 @@ class FeatureStore:
             statistics_config=statistics_config,
             label=label,
             coalesce=coalesce,
+            transformation_functions=transformation_functions,
         )
 
     def create_expectation(
@@ -559,6 +580,89 @@ class FeatureStore:
             featurestore_id=self._id,
         )
 
+    def create_transformation_function(
+        self,
+        transformation_function: callable,
+        output_type: Union[
+            str,
+            TypeVar("str"),  # noqa: F821
+            TypeVar("string"),  # noqa: F821
+            bytes,
+            numpy.int8,
+            TypeVar("int8"),  # noqa: F821
+            TypeVar("byte"),  # noqa: F821
+            numpy.int16,
+            TypeVar("int16"),  # noqa: F821
+            TypeVar("short"),  # noqa: F821
+            int,
+            TypeVar("int"),  # noqa: F821
+            numpy.int,
+            numpy.int32,
+            numpy.int64,
+            TypeVar("int64"),  # noqa: F821
+            TypeVar("long"),  # noqa: F821
+            TypeVar("bigint"),  # noqa: F821
+            float,
+            TypeVar("float"),  # noqa: F821
+            numpy.float,
+            numpy.float64,
+            TypeVar("float64"),  # noqa: F821
+            TypeVar("double"),  # noqa: F821
+            datetime.datetime,
+            numpy.datetime64,
+            datetime.date,
+            bool,
+            TypeVar("boolean"),  # noqa: F821
+            TypeVar("bool"),  # noqa: F821
+            numpy.bool,
+        ],
+        version: Optional[int] = None,
+    ):
+        """Create a transformation function metadata object.
+
+        !!! note "Lazy"
+            This method is lazy and does not persist the transformation function in the
+            feature store on its own. To materialize the transformation function and save
+            call the `save()` method of the transformation function metadata object.
+
+        # Arguments
+            transformation_function: callable object.
+            output_type: python or numpy output type that will be inferred as pyspark.sql.types type.
+
+        # Returns:
+            `TransformationFunction`: The TransformationFunction metadata object.
+        """
+        return TransformationFunction(
+            featurestore_id=self._id,
+            transformation_fn=transformation_function,
+            output_type=output_type,
+            version=version,
+        )
+
+    def get_transformation_function(
+        self,
+        name: str,
+        version: Optional[int] = None,
+    ):
+        """Get  transformation function metadata object.
+
+        # Arguments
+            name: name of transformation function.
+            version: version of transformation function. Optional, if not provided all functions that match to provided
+                name will be retrieved .
+        # Returns:
+            `TransformationFunction`: The TransformationFunction metadata object.
+        """
+        return self._transformation_function_engine.get_transformation_fn(name, version)
+
+    def get_transformation_functions(self):
+        """Get  all transformation functions metadata objects.
+
+        # Returns:
+             `List[TransformationFunction]`. List of transformation function instances.
+        """
+        return self._transformation_function_engine.get_transformation_fns()
+
     @property
     def id(self):
         """Id of the feature store."""
