@@ -627,12 +627,12 @@ class SnowflakeConnector(StorageConnector):
             "database": self._database,
             "schema": self._schema,
         }
-        if self._password is not None:
+        if self._password:
             props["password"] = self._password
         else:
             props["authenticator"] = "oauth"
             props["token"] = self._token
-        if self._warehouse is not None:
+        if self._warehouse:
             props["warehouse"] = self._warehouse
         return props
 
@@ -645,16 +645,16 @@ class SnowflakeConnector(StorageConnector):
         props["sfSchema"] = self._schema
         props["sfDatabase"] = self._database
         props["sfUser"] = self._user
-        if self._password is not None:
+        if self._password:
             props["sfPassword"] = self._password
         else:
             props["sfAuthenticator"] = "oauth"
             props["sfToken"] = self._token
-        if self._warehouse is not None:
+        if self._warehouse:
             props["sfWarehouse"] = self._warehouse
-        if self._role is not None:
+        if self._role:
             props["sfRole"] = self._role
-        if self._table is not None:
+        if self._table:
             props["dbtable"] = self._table
 
         return props
@@ -714,9 +714,12 @@ class JdbcConnector(StorageConnector):
         """Return prepared options to be passed to Spark, based on the additional
         arguments.
         """
-        args = [arg.split("=") for arg in self._arguments.split(",")]
+        options = (
+            {a[0]: a[1] for a in [arg.split("=") for arg in self._arguments.split(",")]}
+            if self._arguments
+            else {}
+        )
 
-        options = {a[0]: a[1] for a in args}
         options["url"] = self._connection_string
 
         return options
